@@ -101,8 +101,12 @@ class MinioAgent(ABC):
 
     def has_object_not_been_analysed(self, object_name: str, bucket_name: str) -> bool:
         tags = self.client.get_object_tags(bucket_name, object_name)
-        if not tags or tags[f"{self.name}-processed"] == "False":
-            return True
+        if tags:
+            try:
+                if tags[f"{self.name}-processed"] == "False":
+                return True
+            except KeyError:
+                return False
         else:
             return False
 
